# commitizen-emoji

![Console print](img/console.gif)

## What is it

Its a customization for [commitizen](https://github.com/commitizen-tools/commitizen)

## Installation

`pip install commitizen-emoji`

## Usage

`cz -n cz_commitizen_emoji c`

## Author

Marcelo Maia (mmaia.cc@gmail.com)
